@@ -3,6 +3,7 @@ from types import FunctionType
 from typing import Optional
 
 import ppb
+from ppb.events import *
 from ppb.systemslib import System
 from ppb.utils import get_time
 
@@ -23,12 +24,11 @@ class Timer:
 
 
 class Timers(System):
-    timers = set()
 
     @classmethod
     def delay(cls, seconds, func):
         t = Timer(get_time() + seconds, func)
-        cls.timers.add(t)
+        cls.scene.timers.add(t)
         return t
     
     @classmethod
@@ -36,13 +36,22 @@ class Timers(System):
         n = get_time()
         until = until if until is None else n + until
         t = Timer(n + seconds, func, repeating=seconds, until=until)
-        cls.timers.add(t)
+        cls.scene.timers.add(t)
         return t
+    
+    @classmethod
+    def on_scene_started(cls, ev: SceneStarted, signal):
+        ev.scene.timers = set()
+        cls.scene = ev.scene
+    
+    @classmethod
+    def on_scene_continued(cls, ev: SceneContinued, signal):
+        cls.scene = ev.scene
 
     @classmethod
-    def on_idle(cls, idle, signal):
+    def on_update(cls, ev: Update, signal):
         clear = []
-        for t in list(cls.timers):
+        for t in list(ev.scene.timers):
             if t.clear:
                 clear.append(t)
             else:
@@ -56,7 +65,7 @@ class Timers(System):
                             continue
                     clear.append(t)
         for t in clear:
-            cls.timers.remove(t)
+            cls.scene.timers.remove(t)
 
 
 delay = Timers.delay
